@@ -4,12 +4,12 @@ require 5.003000;
 
 use strict;
 use warnings;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-use Fcntl;
+use vars qw($VERSION @ISA @EXPORT_OK);
+use Fcntl qw(O_RDONLY);
 use integer;
 use Carp qw(croak);
 
-$VERSION = '5.95';
+$VERSION = '5.96';
 
 require Exporter;
 @ISA = qw(Exporter);
@@ -1579,12 +1579,15 @@ The author is particularly grateful to
 	Gunnar Wolf
 	Adam Woodbury
 
-"Believe it I don't."
-- Torvic Drewmel
+"A candle in the bar was lighting up the dirty windows, on one of
+which was a notice, in white enamel letters, telling customers they
+could bring their own food: ON PEUT APPORTER SON MANGER, from which
+the M and the last R were missing."
+- Maigret's War of Nerves
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2003-2014 Mark Shelor
+Copyright (C) 2003-2016 Mark Shelor
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
